##  Choosing Inbox Domain and Asset Type
In the Inbox Domain and Asset Type fields, choose the domain where the assets need to be created and specify the type of assets that need to be created with respect to the fact sheet being mapped.
Subsequently, the integration will create an asset corresponding to each fact sheet within the chosen asset type under the specified domain.
**Note**
Moving Mapped Assets into Different Domains
If required, you can relocate mapped assets into different domains at a later stage. The integration will continue to update the name, fields, and responsibilities of these assets without reverting the changes made to the domain location.
